@@ -83,8 +83,10 @@ def fix_nonpositive_semidefinite(matrix, fix_method="spectral"):
     else:
         raise NotImplementedError("Method {} not implemented".format(fix_method))
 
-    if not _is_positive_semidefinite(fixed_matrix):
-        warnings.warn("Could not fix matrix. Please try a different risk model.")
+    if not _is_positive_semidefinite(fixed_matrix):  # pragma: no cover
+        warnings.warn(
+            "Could not fix matrix. Please try a different risk model.", UserWarning
+        )
 
     # Rebuild labels if provided
     if isinstance(matrix, pd.DataFrame):
@@ -109,7 +111,6 @@ def risk_matrix(prices, method="sample_cov", **kwargs):
         - ``sample_cov``
         - ``semicovariance``
         - ``exp_cov``
-        - ``min_cov_determinant``
         - ``ledoit_wolf``
         - ``ledoit_wolf_constant_variance``
         - ``ledoit_wolf_single_factor``
@@ -127,8 +128,6 @@ def risk_matrix(prices, method="sample_cov", **kwargs):
         return semicovariance(prices, **kwargs)
     elif method == "exp_cov":
         return exp_cov(prices, **kwargs)
-    elif method == "min_cov_determinant":
-        return min_cov_determinant(prices, **kwargs)
     elif method == "ledoit_wolf" or method == "ledoit_wolf_constant_variance":
         return CovarianceShrinkage(prices, **kwargs).ledoit_wolf()
     elif method == "ledoit_wolf_single_factor":
@@ -272,24 +271,9 @@ def exp_cov(prices, returns_data=False, span=180, frequency=252, **kwargs):
 
 def min_cov_determinant(
     prices, returns_data=False, frequency=252, random_state=None, **kwargs
-):
-    """
-    Calculate the minimum covariance determinant, an estimator of the covariance matrix
-    that is more robust to noise.
+):  # pragma: no cover
+    warnings.warn("min_cov_determinant is deprecated and will be removed in v1.5")
 
-    :param prices: adjusted closing prices of the asset, each row is a date
-                   and each column is a ticker/id.
-    :type prices: pd.DataFrame
-    :param returns_data: if true, the first argument is returns instead of prices.
-    :type returns_data: bool, defaults to False.
-    :param frequency: number of time periods in a year, defaults to 252 (the number
-                      of trading days in a year)
-    :type frequency: int, optional
-    :param random_state: random seed to make results reproducible, defaults to None
-    :type random_state: int, optional
-    :return: annualised estimate of covariance matrix
-    :rtype: pd.DataFrame
-    """
     if not isinstance(prices, pd.DataFrame):
         warnings.warn("data is not in a dataframe", RuntimeWarning)
         prices = pd.DataFrame(prices)
@@ -303,10 +287,11 @@ def min_cov_determinant(
     assets = prices.columns
 
     if returns_data:
-        X = prices.dropna(how="all")
+        X = prices
     else:
-        X = prices.pct_change().dropna(how="all")
-    X = np.nan_to_num(X.values)
+        X = returns_from_prices(prices)
+    # X = np.nan_to_num(X.values)
+    X = X.dropna().values
     raw_cov_array = sklearn.covariance.fast_mcd(X, random_state=random_state)[1]
     cov = pd.DataFrame(raw_cov_array, index=assets, columns=assets) * frequency
     return fix_nonpositive_semidefinite(cov, kwargs.get("fix_method", "spectral"))
@@ -342,7 +327,7 @@ def corr_to_cov(corr_matrix, stdevs):
     :rtype: pd.DataFrame
     """
     if not isinstance(corr_matrix, pd.DataFrame):
-        warnings.warn("cov_matrix is not a dataframe", RuntimeWarning)
+        warnings.warn("corr_matrix is not a dataframe", RuntimeWarning)
         corr_matrix = pd.DataFrame(corr_matrix)
 
     return corr_matrix * np.outer(stdevs, stdevs)
@@ -377,7 +362,7 @@ class CovarianceShrinkage:
             from sklearn import covariance
 
             self.covariance = covariance
-        except (ModuleNotFoundError, ImportError):
+        except (ModuleNotFoundError, ImportError):  # pragma: no cover
             raise ImportError("Please install scikit-learn via pip or poetry")
 
         if not isinstance(prices, pd.DataFrame):
